import java.util.Iterator;

/**
 * Annuaire tlphonique permettant d'associer  une Personne une liste de numros de tlphones.
 *
 * <br>Created: Tue Dec 04 21:25:14 2001
 *
 * @see NumTel
 * @see Personne
 * @see ListeNumTel
 * @author <a href="mailto:Philippe.Genoud@imag.fr">Philippe Genoud</a>
 * @version
 */

public interface Annuaire {
    
    /**
     * ajoute une nouvelle entre dans l'annuaire. Si p n'existe pas: on cre une nouvelle
     * association (p,nums) et le booleen <code>true</code> est retourn; sinon le booleen
     * <code>/false</code> est retourn et la mthode est sans effet.
     *
     * @param p la personne
     * @param nums sa liste de numeros
     * @return <code>true</code>si l'entre a t ajoute, <code>false</code> si la personne
     *        <oce>p</code> tait dj prsente dans l'annuaire
     */
    public boolean ajouterEntree(Personne p, ListeNumTel nums) ;
    
    /**
     * ajoute un numero  la fin de la liste des numros d'une personne.
     * Si la personne n'existe pas on cre une nouvelle entre pour cette personne avec
     * comme liste de numros associe la liste constitue du numro pass en paramtre.
     *
     * @param p la personne
     * @param n le numero  ajouter
     */
    public void ajouterNumeroFin(Personne p, NumTel n) ;
    
    /**
     * ajoute un numero au dbut de la liste des numros d'une personne.
     * Si la personne n'existe pas on cre une nouvelle entre pour cette personne avec
     * comme liste de numros associe la liste constitue du numro pass en paramtre.
     *
     * @param p la personne
     * @param n le numero  ajouter
     */
    
    public void ajouterNumeroDebut(Personne p, NumTel n) ;
    
    /**
     * retourne le premier numro d'une personne, si la personne n'est pas dans 
     * l'annuaire retourne null.
     * @param p la personne dont on recherche le numro
     * @return son numero, <code>null</code> si p n'est pas prsente dans l'annuaire.
     */
    public NumTel premierNumero(Personne p) ;
    
    /**
     * retourne la liste des numros d'une personne si la personne est absente 
     * retourne null
     * @param o la personne pour laquelle on consulte les numeros.
     * @return la liste des numros de la personne si celle-ci est prsente dans
     *         l'annuaire, <code>null</code> sinon.
     */
    public ListeNumTel numeros(Personne p) ;
    
    
    /**
     * renvoie un iterateur sur l'ensemble des personnes contenues dans l'annuaire
     * @return l'iterateur
     */
    public Iterator personnes();
    
    /**
     * affiche l'intgralit de l'annuaire, sous la forme d'une personne par ligne
     * suivie de ses numros de tlphone.
     */
    public void afficher();
    
    /**
     * supprime une personne de l'annuaire. Sans effet si la persoone n'est pas 
     * prsente dans l'annuaire.
     * @param p la personne  retirer de l'annuaire.
     */
    public void supprimer(Personne p);
    
    
    /**
     * supprime un numero donn pour une personne.<BR>
     * Si ce numro est le seul numro pour la  personne, la personne est 
     * alors retire de l'annuaire.<BR>
     * Sans effet si la personne n'est pas prsente dans l'annuaire.
     * @param p la personne pour laquelle un numro doit tre supprim.
     * @param n le numero a supprimer.
     */
    public void supprimer(Personne p, int n) ;
    
    
}// Annuaire
