import java.util.Iterator;

/**
 *
 * Reprsente une liste de numros de tlphone.  
 * La liste contient au moins un numro (pas de liste vide).
 *
 * <br>Created: Tue Dec 04 21:09:56 2001
 * 
 * @see NumTel
 * @author <a href="mailto:Philippe.Genoud@imag.fr">Philippe Genoud</a>
 * @version 1.0
 */

public interface ListeNumTel {

  /**
   * ajoute un numro  la fin de la liste, sans effet si le numro est dj 
   * prsent dans la liste.
   * @param num le numro  ajouter
   * @return <code>true</code> si le numro a t ajout, <code>false</code> si l'ajout
   *        n'a pas eu lieu car la liste contient dj le numro.
   */
  public boolean ajouterFin(NumTel num) ;

   /**
   * ajoute un numro au dbut de la liste, sans effet si le numro est dj 
   * prsent dans la liste.
   * @param num le numro  ajouter
   * @return <code>true</code> si le numro a t ajout, <code>false</code> si l'ajout
   *        n'a pas eu lieu car la liste contient dj le numro.
   */
  public boolean ajouterDebut(NumTel num) ;
  
  
  /**
   * ajoute un numro  une position donne dans la liste, sans effet si le numro est dj 
   * prsent dans la liste.
   * @param int index la position d'insertion dans la liste
   * @param num le numro  ajouter
   * @return <code>true</code> si le numro a t ajout, <code>false</code> si l'ajout
   *        n'a pas eu lieu car la liste contient dj le numro.
   */
  public boolean ajouter(int index, NumTel num) ;

  /**
   * retourne le premier numro de la liste (il existe forcment) 
   * @return le premier numro de la liste.
   */
  public NumTel premierNumero() ;
  
  /**
   * retourne le ime numro de la liste, <code>null</code> si la liste contient
   * moins de <code>i</code> numros. 
   * @param index la position du numro  rechercher 
   * @return le numero de la liste  la position index.
   */
  public NumTel numero(int index ) ;
 
 /**
  * Teste la prsence d'un numro dans la liste.
  * @param num le numro  rechercher.
  * @return <code>true</code> si la liste contient le objet Numtel dont le numro est
  *         identique  <code>num</code>, false sinon
  */
  public boolean contientNumero(int num) ;

 /**
  * retourne le nombre de numros de la liste (>=1).
  * @return nombre de numros prsents dans la liste.
  */
  public int nbNumeros() ;

  /**
   * Retourne dans une chane de caractres la squence des numros contenu dans
   * cette liste. Dans la chane rsultat les numros sont spars par des virgules.
   * <BR>
   * exemple:<BR><pre>
   * 0476088634 (D), 0654789045 (P), 0476615277 (T)
   * </pre><BR>
   * @return la chaine contenant la squence des numros.
   */ 
  public String toString() ;

  /**
   * Renvoie un itrateur sur les numros de tlphone contenus dans la liste.
   *
   * @return un iterateur permettant le parcours des numros de la liste
   */
   public Iterator iterator() ;
   
  /**
   * Enlve un numro de la liste, cette opration n'est possible que si la liste
   * contient au moins deux numros (nbNumero()>1). Si la liste ne contient contient
   * qu'un seul numro cette opration est sans effet. De mme si le numro spcifi 
   * n'est pas prsent dans la liste.<br>
   * Cette mthode retourne un boolen qui indique si cette liste de numros de tlphone
   * a t affecte par l'opration de retrait.
   *
   * @param num le numero  enlever.
   * 
   * @return <code>true</code> si un NumTel dont le numro est num a t retir de la liste,
   *         <code>false</code> si la liste ne contient plus qu'un seul numro ou si il n'y
   *         a pas dans la liste de NumTel de numro num.
   */
  public boolean retirer(int num);
  
  
}// ListeNumTel

